
Object.defineProperty(exports, "__esModule", { value: true });
let eventIds = new Map();
let subscribeFunction = function (prefix, handlerId, deviceId) {
    try {
        let handler = new io.particle.android.sdk.cloud.ParticleEventHandler({
            onEventError: function (exception) {
                self.postMessage({ success: false });
            },
            onEvent: function (eventName, event) {
                if (event) {
                    self.postMessage({
                        success: true,
                        handlerId: handlerId,
                        data: {
                            prefix: prefix,
                            event: eventName,
                            data: event.dataPayload,
                            date: new Date(event.publishedAt.getTime()),
                            deviceID: event.deviceId
                        }
                    });
                }
            }
        });
        let id = deviceId ? io.particle.android.sdk.cloud.ParticleCloudSDK.getCloud().subscribeToDeviceEvents(prefix, deviceId, handler)
            : io.particle.android.sdk.cloud.ParticleCloudSDK.getCloud().subscribeToAllEvents(prefix, handler);
        eventIds.set(prefix, id);
    } catch (e) {
        console.log(e.nativeException.getBestMessage());
    }
};
let unsubscribeFunction = function (prefix) {
    if (eventIds.has(prefix)) {
        io.particle.android.sdk.cloud.ParticleCloudSDK.getCloud().unsubscribeFromEventWithID(eventIds.get(prefix));
        eventIds.delete(prefix);
    }
};
self.onmessage = function (msg) {
    let request = msg.data;
    if (request.action === "subscribe") {
        subscribeFunction(request.options.prefix, request.options.handlerId);

        return;
    } else if (request.action === "unsubscribe") {
        unsubscribeFunction(request.options.prefix);

        return;
    } else if (request.action === "subscribeDevice") {
        subscribeFunction(request.options.prefix, request.options.handlerId, request.options.deviceId);

        return;
    } else if (request.action === "unsubscribeDevice") {
        unsubscribeFunction(request.options.prefix);

        return;
    } else {
        self.postMessage({ success: false, error: "Unsupported action sent to worker: '" + request.action + "'" });
    }
};
