
Object.defineProperty(exports, "__esModule", { value: true });
let particle_worker_base_1 = require("./particle-worker-base");
let cachedDevices;
let login = function (options) {
    try {
        io.particle.android.sdk.cloud.ParticleCloudSDK.getCloud().logIn(options.username, options.password);
        self.postMessage({ success: true });
    } catch (e) {
        self.postMessage({ success: false, error: e.nativeException.getBestMessage() });
    }
};
let listDevices = function () {
    try {
        let particleDevices = io.particle.android.sdk.cloud.ParticleCloudSDK.getCloud().getDevices();
        cachedDevices = [];
        for (let i = 0; i < particleDevices.size(); i++) {
            cachedDevices.push(new particle_worker_base_1.MyTNSParticleDevice(particleDevices.get(i)));
        }
        self.postMessage({ success: true, devices: cachedDevices });
    } catch (e) {
        self.postMessage({ success: false, error: e.nativeException.getBestMessage() });
    }
};
let getVariable = function (device, name) {
    device.getVariable(name)
        .then(function (result) { return (self.postMessage({ success: true, result: result })); })
        .catch(function (error) { return self.postMessage({ success: false, error: error }); });
};
let callFunction = function (device, name, args) {
    device.callFunction(name, args)
        .then(function (result) { return self.postMessage({ success: true, result: result }); })
        .catch(function (error) { return self.postMessage({ success: false, error: error }); });
};
let renameDevice = function (device, name) {
    device.rename(name)
        .then(function (result) { return self.postMessage({ success: true }); })
        .catch(function (error) { return self.postMessage({ success: false, error: error }); });
};
let unclaimDevice = function (device) {
    device.unclaim()
        .then(function (result) { return self.postMessage({ success: true }); })
        .catch(function (error) { return self.postMessage({ success: false, error: error }); });
};
let publish = function (name, data, isPrivate, ttl) {
    io.particle.android.sdk.cloud.ParticleCloudSDK.getCloud().publishEvent(name, data, isPrivate ? io.particle.android.sdk.cloud.ParticleEventVisibility.PRIVATE : io.particle.android.sdk.cloud.ParticleEventVisibility.PUBLIC, ttl);
};
let getDevice = function (id) {
    return cachedDevices.filter(function (cachedDevice) { return cachedDevice.id === id; })[0];
};
self.onmessage = function (msg) {
    let request = msg.data;
    if (request.action === "login") {
        login(request.options);

        return;
    } else if (request.action === "listDevices") {
        listDevices();

        return;
    } else if (request.action === "rename") {
        renameDevice(getDevice(request.options.deviceId), request.options.name);

        return;
    } else if (request.action === "unclaim") {
        unclaimDevice(getDevice(request.options.deviceId));

        return;
    } else if (request.action === "callFunction") {
        callFunction(getDevice(request.options.deviceId), request.options.name, request.options.args);

        return;
    } else if (request.action === "getVariable") {
        getVariable(getDevice(request.options.deviceId), request.options.name);

        return;
    } else if (request.action === "publish") {
        publish(request.options.name, request.options.data, request.options.isPrivate, request.options.ttl);

        return;
    } else {
        self.postMessage({ success: false, error: "Unsupported action sent to worker: '" + request.action + "'" });
    }
};
