export declare type TNSParticleDeviceType = "Unknown" | "Core" | "Photon" | "P1" | "Electron" | "RaspberryPi" | "DigistumpOak" | "RedBearDuo" | "Bluz";
export declare type VariableType = "INT" | "DOUBLE" | "STRING";
export declare function getDeviceType(id: number): TNSParticleDeviceType;
export interface TNSParticleDeviceVariable {
    name: string;
    type: VariableType;
}
export interface TNSParticleEvent {
    prefix: string;
    event: string;
    data: string;
    date: Date;
    deviceID: string;
}
export interface TNSParticleDevice {
    id: string;
    name: string;
    status: string;
    connected: boolean;
    productId: number;
    type: TNSParticleDeviceType;
    functions: Array<string>;
    variables: Array<TNSParticleDeviceVariable>;
    eventIds: Map<string, any>;
    rename: (name: string) => Promise<void>;
    unclaim: () => Promise<void>;
    getVariable: (name: string) => Promise<any>;
    callFunction: (name: string, ...args: any[]) => Promise<number>;
    subscribe: (prefix: string, eventHandler: (event: TNSParticleEvent) => void) => void;
    unsubscribe: (prefix: string) => void;
}
export interface TNSParticleLoginOptions {
    username: string;
    password: string;
}
export interface TNSParticleAPI {
    login(options: TNSParticleLoginOptions): Promise<void>;
    loginWithToken(token: string, productId: number): void;
    setOAuthConfig(id: string, secret: string): void;
    logout(): void;
    isAuthenticated(): boolean;
    accessToken(): string;
    listDevices(productId: number): Promise<Array<TNSParticleDevice>>;
    startDeviceSetupWizard(productId: number): Promise<boolean>;
    getDeviceSetupCustomizer(): any;
    subscribe(prefix: string, eventHandler: (event: TNSParticleEvent) => void, productId: number): void;
    unsubscribe(prefix: string, productId: number): void;
    publish(name: string, data: string, isPrivate: boolean, ttl: number, productId: number): Promise<void>;
    authIfNeeded(productId: number): void;
}
